@@ -1,7 +1,8 @@
+use core::mem::MaybeUninit;
+
 use std::net::{IpAddr, SocketAddr};
 use std::time::Duration;
 
-use rand::random;
 use socket2::{Domain, Protocol, Socket, Type};
 
 use crate::errors::Error;
@@ -27,11 +28,11 @@ pub fn ping(
     let dest = SocketAddr::new(addr, 0);
     let mut buffer = [0; ECHO_REQUEST_BUFFER_SIZE];
 
-    let default_payload: &Token = &random();
+    let default_payload: &Token = &[0; TOKEN_SIZE];
 
     let request = EchoRequest {
-        ident: ident.unwrap_or_else(random),
-        seq_cnt: seq_cnt.unwrap_or(1),
+        ident: ident.unwrap_or(0),
+        seq_cnt: seq_cnt.unwrap_or(0),
         payload: payload.unwrap_or(default_payload),
     };
 
@@ -39,12 +40,12 @@ pub fn ping(
         if request.encode::<IcmpV4>(&mut buffer[..]).is_err() {
             return Err(Error::Internal);
         }
-        Socket::new(Domain::ipv4(), Type::raw(), Some(Protocol::icmpv4()))?
+        Socket::new(Domain::IPV4, Type::RAW, Some(Protocol::ICMPV4))?
     } else {
         if request.encode::<IcmpV6>(&mut buffer[..]).is_err() {
             return Err(Error::Internal);
         }
-        Socket::new(Domain::ipv6(), Type::raw(), Some(Protocol::icmpv6()))?
+        Socket::new(Domain::IPV6, Type::RAW, Some(Protocol::ICMPV6))?
     };
 
     socket.set_ttl(ttl.unwrap_or(64))?;
@@ -55,8 +56,10 @@ pub fn ping(
 
     socket.set_read_timeout(timeout)?;
 
-    let mut buffer: [u8; 2048] = [0; 2048];
-    socket.recv_from(&mut buffer)?;
+    let buffer: [u8; 2048] = [0; 2048];
+    let mut maybe_uninit_buffer: [MaybeUninit<u8>; 2048] = [MaybeUninit::new(0); 2048];
+    //let mut buffer = vec![0; 2048];
+    socket.recv_from(&mut maybe_uninit_buffer)?;
 
     let _reply = if dest.is_ipv4() {
         let ipv4_packet = match IpV4Packet::decode(&buffer) {
